谍影重重2 (豆瓣)
Description: 谍影重重2电影简介和剧情介绍,谍影重重2影评、图片、预告片、影讯、论坛、在线购票
Keywords: 谍影重重2,The Bourne Supremacy,谍影重重2影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.234豆瓣电影Top250

# 谍影重重2 The Bourne Supremacy (2004)

导演: 保罗·格林格拉斯
编剧: 罗伯特·鲁德鲁姆 / 托尼·吉尔罗伊
主演: 马特·达蒙 / 布莱恩·考克斯 / 琼·艾伦 / 卡尔·厄本 / 弗朗卡·波滕特 / 朱丽娅·斯蒂尔斯 / 加布里埃尔·曼 / 马尔顿·索克斯 / 汤姆·加洛普 / 约翰·贝德福德·劳埃德 / 伊桑·桑德勒 / 米歇尔·莫纳汉 / 卡瑞尔·罗登 / 托马斯·阿拉纳 / 奥莎娜·阿金什那 / Yevgeni Sitokhin / 蒂姆·格里芬 / 肖恩·史密斯 / 马克西姆·科瓦莱夫斯基 / 帕特里克·克劳利 / 乔恩·科林·巴克利 / 谢恩·辛努特科 / Claudio Maniscalco / Dirk Schoedon / 伊万·舍甫多夫 / 丹尼斯·布尔加兹列夫 / Nick Wilder / 维克多·埃菲尔 / 埃莱娜·卡多纳 / 克里斯·库珀
类型: 动作 / 悬疑 / 惊悚
官方网站: www.thebournesupremacy.com
制片国家/地区: 美国 / 德国
语言: 英语 / 俄语 / 德语 / 意大利语
上映日期: 2004-11-14(中国大陆) / 2004-07-15(洛杉矶首映) / 2004-07-23(美国)
片长: 108分钟
又名: 叛谍追击2：机密圈套(港) / 神鬼认证：神鬼疑云(台) / 伯恩的身份2 / 至尊伯恩 / 伯恩的霸权
IMDb: tt0372183
豆瓣评分
引用
8.7
334597人评价
5星
45.9%
4星
43.4%
3星
10.1%
2星
0.5%
1星
0.1%
好于 98% 动作片
好于 98% 悬疑片
想看 看过
评价:
推荐

## 谍影重重2的剧情简介 · · · · · ·

经过上一集的腥风血雨之后，伯恩（马特·达蒙 饰）和女朋友玛丽（弗兰卡·泼坦特 饰）隐居在印度偏僻的海边小镇，想忘记以前的生活。一天，神秘组织的杀手来到小镇，打破了伯恩二人世界的宁静，女友玛丽在逃亡途中被枪杀。
为了查出真相，伯恩重新开始战斗，他发现以前工作的中情局开始重新寻找他，自己被卷入了一场刺杀活动中，被人诬陷破坏了中情局的一次情报交易，杀害特工。伯恩别无选择，他只能找到冒充自己的人，才能洗刷清白，为女友报仇。 ©豆瓣

## 谍影重重2的演职员 · · · · · · ( 全部 52 )

- 保罗·格林格拉斯 导演
- 马特·达蒙 饰 Jason Bourne
- 布莱恩·考克斯 饰 Ward Abbott
- 琼·艾伦 饰 Pamela Landy
- 卡尔·厄本 饰 Kirill
- 弗朗卡·波滕特 饰 Marie

## 谍影重重2的图片 · · · · · · ( 添加视频评论 | 图片306 · 添加 )

## 谍影重重2的获奖情况 · · · · · · ( 全部 )

- 第14届MTV电影奖
- MTV电影奖 最佳男演员(提名)
- 马特·达蒙

- 第14届MTV电影奖
- MTV电影奖 最佳动作场面(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  谍影重重3

  勇闯夺命岛

  碟中谍

  飓风营救

  变脸

  速度与激情5

  终结者2：审判日

  黑客帝国3：矩阵革命

  记忆碎片

  禁闭岛

我要写短评

## 谍影重重2的短评 · · · · · · ( 全部 41076 条 )

热门 / 最新 / 好友

### 1019 有用 Song³ 看过 2009-04-26 20:23:25

拍摄利落。全片大量采用了近景跟随拍摄，追逐逃亡场景用极短的镜头剪接连缀，没有用近几年时髦的慢动作、子弹时间、镜头满天转等特效。但是一样达到了让人屏住呼吸、目瞪口呆的效果。汽车追逐片断中近距离车内拍摄的碰撞场面尤其惊心动魄，远比其他动作片中动辄撞坏十几辆车来的惊险刺激。

### 591 有用 暖鱼 看过 2007-08-18 02:50:07

整个片子干净利落，扣人心弦。对自我身份的确认与对过去的救赎又让影片多一份厚重。

### 520 有用 D I D A 看过 2010-02-02 15:06:08

手提摄影，快速剪辑，身体力行，暗藏杀机。间谍动作片由此洗牌

### 1570 有用 Baristina 看过 2012-09-06 15:41:02

俄罗斯出租质量真好

### 1025 有用 阿底 看过 2008-03-17 08:49:20

伯恩在水下亲吻玛丽的那段，真是又美丽，又悲伤，唉。

> 更多短评 41076条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 谍影重重2的影评 · · · · · · ( 全部 207 条 )

热门 / 最新 / 好友
Jason Bourne 2007-12-05 14:29:27

## 根据影片自己总结的特工技巧【散乱，不成熟，欢迎补充！】

【Bourne系列三部中的技巧均已总结，详情参见另外两部】自我出生以来，看过的最具个人高技术、高智商含量的电影！如果还有哪部，各位认为是超出这部的，恳请赐教！ 　　简评下吧： 　　1，剧情精彩，情节设计合理，几臻圆满，充满调动观者思考积极性的元素【其中逻辑性严密程... (展开)
443 54 69回应 收起
包爸 2005-10-15 02:19:31

## 嘎嘣利落脆！

1）剧情利落。这个片子基本上没费一点力气去营造若干个套绕观众，好坏人物也几乎一出场就让人明白了他们的身份，叙事风格完全是单线的。沉的住气，一步一步慢慢把故事从容的讲完，冬冬我就喜欢这种具有五、六十年代优雅风格的间谍片。 2）人物利落。片中以Bourne为代表的人物... (展开)
310 20 33回应 收起
herb 2009-03-04 20:25:17

## 潦草笔记之《谍影重重２》

画面多晃动，构图不稳定，尤其两人对话时常从一方肩膀后拍对方，不求脸部完整。 下属单独向艾毕汇报疑点时，俯拍仰拍来回切，预示将被灭口。 色彩以黑灰银为主，冷峻肃杀，也与主要取景地柏林、莫斯科的气质气候吻合。 例外之处有两处印象深的：一是在印度，风车、气球甚至小... (展开)
268 20 29回应 收起
kathleen9 2007-08-01 17:23:00

## 喜欢这个男人

很久以前我看过一版无线的《东邪西毒》，黄药师为了阿衡几乎扫平名门正派。奈何美好的事物总不长存，两人相守不久后阿衡重病。临死前，她拉着黄药师的手殷殷嘱托：为了我，求你少杀人。从此东邪不忘阿衡嘱托，能不杀就不杀。 很长一段时间我在寻找这样的影像，与记忆中的药师... (展开)
229 14 36回应 收起
liweijiang 2016-04-16 16:52:07

## 伯恩的推理

这篇影评可能有剧透

背景介绍：七年前，中情局的一笔两千万美金在经过莫斯科的电汇中不翼而飞，一个脚耐斯基的俄罗斯政客与中情局取得联系，说中情局内部有叛徒，中情局被内部人事打劫，在中情局与耐斯基谈判时，耐斯基被杀害（被伯恩所杀），案件无法进展。另一名在柏林的俄罗斯人声称他有耐斯基... (展开)
81 1 12回应 收起
五号屠场 2011-07-16 19:33:16

## [关于谍影重重系列]

在碟战题材的系列电影里面，恐怕没有哪个系列可以和谍影重重叫板。 碟中谍系列呢，我觉得阿汤哥喜欢耍酷，他每次任务的完成更多地是团队合作的结果。 007系列，以前的没怎么看，最近几部，我觉得邦德的打斗太过血腥，没有美感。 所以哥一直很中意谍影重重系列。 伯恩不算帅，至... (展开)
80 4 5回应 收起
judecheng 2008-04-28 17:18:10

## 我感觉好过第一部

超越了第一部，叙事与影像上更加风格化，非常喜欢这种异常凌厉简洁的风格。还有结尾颇令人感慨，面对万家灯火，却无一人陪伴，只能继续逃亡。 (展开)
67 4 13回应 收起
快乐卟卟 2017-08-18 15:47:27

## 依然好看

马特还是一如既往地帅，电影节奏比第一部要快，情节紧扣生死和感情，冲击力很足，桥段在围捕和逃脱中尽显人物的智谋，伯恩的手段精明又有效率，动作场景太燃，飙车戏尤其让人过瘾。悬疑的剧情和配乐让效果更加突出，保持了悬疑惊悸的味道，整体比第一部只好不坏，但让我感觉不... (展开)
27 0回应 收起
爱吃馒头的宝宝 2017-07-22 13:35:39

## 一个人的战斗

这篇影评可能有剧透

作为承上启下的第二部，影片在呈现上经典延续，依旧维系了其首秀时剧情步步为营，剪辑凌厉逼人的节奏观感，无法平静的生活，一个人的孤军而战，真实不失精彩，冷静而又满是激情，毫无破绽的演绎，马特·达蒙塑造的伯恩堪称完美特工。 谍战片的巅峰，情节紧，节奏快，绝对烧脑。... (展开)
33 3 0回应 收起
里托·贝森 2007-10-20 23:14:45

## 伯恩的精彩之二

这一部换了导演，于是影片的风格与第一部比起来有了些变化。最突出的一点就是镜头的摇晃。几处激战和追逐戏中，镜头一律晃得人头晕，虽说这能够增强观众的现场感，但是我个人觉得有点儿过了。 除了流畅的情节和好看的动作场面之外，本片最大的亮点是让伯恩这个人物更加丰满了... (展开)
20 3 0回应 收起

> 更多影评 207篇

添加新讨论

## 讨论区 · · · · · ·

假如杰森伯恩来到中国，哈哈哈 | 来自张克岳 | 8 回应 | 2022-11-01 03:53:25
片中的欧洲和美国还真是鲜明对比 | 来自雾眼~ | 2 回应 | 2022-11-01 03:48:50
为什么？ | 来自爽 朗 | 1 回应 | 2022-10-18 01:44:49
为什么要让女主领盒饭！ | 来自无产者 | 3 回应 | 2022-10-07 21:54:43
看了好几遍 有两个疑问❓附图。 | 来自北北 | 12 回应 | 2022-08-31 15:47:16

> 去这部影片的讨论区（全部99条）

## 关于《谍影重重2》的问题 · · · · · · ( 全部14个 )

- 伯恩在那不勒斯被那个美国领事馆内文斯盘问的时候？ 5人回答
- 伯恩是怎么找到慕尼黑那个特工的？ 3人回答

> 全部14个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 他们是高智商玩家 (中间元素)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- {北美电影票房总排行} (荔枝超人)

## 谁在看这部电影 · · · · · ·

- 若忆起年少时
  3分钟前 看过
- 凡尘
  8分钟前 看过
- momo
  11分钟前 想看

561736人看过 / 75554人想看

订阅谍影重重2的评论:
feed: rss 2.0